@@ -3,7 +3,6 @@
 # modify it under the same terms as Perl itself.
 #
 # Maintained since 2013 by Paul Evans <leonerd@leonerd.org.uk>
-# Since 2015 unauthorized by Reini Urban for cperl (binary names, utf8, lexical $_, ...)
 
 package Scalar::Util;
 
@@ -18,8 +17,8 @@ our @EXPORT_OK = qw(
   dualvar isdual isvstring looks_like_number openhandle readonly set_prototype
   tainted
 );
-our $VERSION    = "1.50_11";
-$VERSION   = eval $VERSION;
+our $VERSION    = "1.52_001";
+$VERSION =~ tr/_//d;
 
 require List::Util; # List::Util loads the XS
 List::Util->VERSION( $VERSION ); # Ensure we got the right XS version (RT#100863)
@@ -277,8 +276,8 @@ L<perlapi/looks_like_number>.
 
     my $fh = openhandle( $fh );
 
-Returns C<$fh> itself if C<$fh> may be used as a filehandle and is open, or is
-is a tied handle. Otherwise C<undef> is returned.
+Returns C<$fh> itself, if C<$fh> may be used as a filehandle and is open, or if
+it is a tied handle. Otherwise C<undef> is returned.
 
     $fh = openhandle(*STDIN);           # \*STDIN
     $fh = openhandle(\*STDIN);          # \*STDIN
