@@ -2,9 +2,6 @@
 # This program is free software; you can redistribute it and/or
 # modify it under the same terms as Perl itself.
 
-# Maintained since 2015 unauthorized by Reini Urban for cperl.
-# set_subname, binary names, utf8
-
 package Sub::Util;
 
 use strict;
@@ -18,8 +15,8 @@ our @EXPORT_OK = qw(
   subname set_subname
 );
 
-our $VERSION    = "1.50_11";
-$VERSION   = eval $VERSION;
+our $VERSION    = "1.52_001";
+$VERSION =~ tr/_//d;
 
 require List::Util; # as it has the XS
 List::Util->VERSION( $VERSION ); # Ensure we got the right XS version (RT#100863)
@@ -98,8 +95,10 @@ I<Since version 1.40.>
 Returns the name of the given C<$code> reference, if it has one. Normal named
 subs will give a fully-qualified name consisting of the package and the
 localname separated by C<::>. Anonymous code references will give C<__ANON__>
-as the localname. If a name has been set using L</set_subname>, this name will
-be returned instead.
+as the localname. If the package the code was compiled in has been deleted
+(e.g. using C<delete_package> from L<Symbol>), C<__ANON__> will be returned as
+the package name. If a name has been set using L</set_subname>, this name will be
+returned instead.
 
 This function was inspired by C<sub_fullname> from L<Sub::Identify>. The
 remaining functions that C<Sub::Identify> implements can easily be emulated
@@ -149,9 +148,6 @@ The general structure of this module was written by Paul Evans
 The XS implementation of L</set_subname> was copied from L<Sub::Name> by
 Matthijs van Duin <xmath@cpan.org>
 
-Support for binary and utf8 names added by Reini Urban <rurban@cpan.org>
-for cperl.
-
 =cut
 
 1;
